test_that('perplexity copied', {
  expect_identical(ds_perplexity, ds_diversity)
})
